@@ -57,4 +57,26 @@ describe 'nova::cron::archive_deleted_rows' do
       )
     end
   end
+
+  context 'cron with maxdelay' do
+    before :each do
+      params.merge!(
+        :maxdelay => 600
+      )
+    end
+
+    it 'configures a cron with maxdelay' do
+      is_expected.to contain_cron('nova-manage db archive_deleted_rows').with(
+        :command     => "sleep `expr ${RANDOM} \\% #{params[:maxdelay]}`; nova-manage db archive_deleted_rows --max_rows #{params[:max_rows]}  >>#{params[:destination]} 2>&1",
+        :environment => 'PATH=/bin:/usr/bin:/usr/sbin SHELL=/bin/sh',
+        :user        => params[:user],
+        :minute      => params[:minute],
+        :hour        => params[:hour],
+        :monthday    => params[:monthday],
+        :month       => params[:month],
+        :weekday     => params[:weekday],
+        :require     => 'Anchor[nova::dbsync::end]',
+      )
+    end
+  end
 end
