@@ -11,7 +11,7 @@ describe Puppet::Provider::Nova do
 
   let :credential_hash do
     {
-      'auth_uri'     => 'https://192.168.56.210:35357/v2.0/',
+      'auth_url'     => 'https://192.168.56.210:35357/v2.0/',
       'project_name' => 'admin_tenant',
       'username'     => 'admin',
       'password'     => 'password',
